@@ -4,8 +4,9 @@
 #include <stdio.h>
 #include "corba-ops.h"
 #include "orb-core-private.h"
-
-#undef DEBUG
+#include "orb-core-export.h"
+#include "orbit-debug.h"
+#include "../util/orbit-purify.h"
 
 /*
  * HashTable of Object Adaptor generated refs that have 
@@ -32,11 +33,6 @@ g_CORBA_Object_equal (gconstpointer a, gconstpointer b)
 	CORBA_Object _obj = (CORBA_Object) a;
 	CORBA_Object other_object = (CORBA_Object) b;
 
-	if(_obj == other_object)
-		return TRUE;
-	if(!(_obj && other_object))
-		return FALSE;
-
 	g_assert (_obj->object_key && other_object->object_key);
 
 	if (!IOP_ObjectKey_equal (_obj->object_key, other_object->object_key))
@@ -46,13 +42,18 @@ g_CORBA_Object_equal (gconstpointer a, gconstpointer b)
 		for (cur2 = other_object->profile_list; cur2; cur2 = cur2->next) {
 			if (IOP_profile_equal (_obj, other_object,
 					       cur1->data, cur2->data)) {
-#if 0
-				char *a, *b;
-				a = IOP_profile_dump (_obj, cur1->data);
-				b = IOP_profile_dump (other_object, cur2->data);
-				fprintf (stderr, "Profiles match:\n'%s':%s\n'%s':%s\n",
-					 _obj->type_id, a, other_object->type_id, b);
-#endif
+#ifdef G_ENABLE_DEBUG
+			        if (_orbit_debug_flags & ORBIT_DEBUG_OBJECTS) {
+					char *a, *b;
+					a = IOP_profile_dump (_obj, cur1->data);
+					b = IOP_profile_dump (other_object, cur2->data);
+					fprintf (stderr, "Profiles match:\n'%s':%s\n'%s':%s\n",
+						           g_quark_to_string (_obj->type_qid), a,
+						           g_quark_to_string (other_object->type_qid), b);
+					g_free (a);
+					g_free (b);
+				}
+#endif /* G_ENABLE_DEBUG */
 				return TRUE;
 			}
 		}
@@ -68,6 +69,7 @@ ORBit_register_objref (CORBA_Object obj)
 		objrefs = g_hash_table_new (
 			g_CORBA_Object_hash, g_CORBA_Object_equal);
 
+	g_assert (obj->object_key != NULL);
 	g_assert (obj->profile_list != NULL);
 
 	g_hash_table_insert (objrefs, obj, obj);
@@ -76,13 +78,7 @@ ORBit_register_objref (CORBA_Object obj)
 static CORBA_Object
 ORBit_lookup_objref (CORBA_Object obj)
 {
-	if (!objrefs) {
-		objrefs = g_hash_table_new (
-			g_CORBA_Object_hash, g_CORBA_Object_equal);
-		return NULL;
-	}
-
-	if (!obj->profile_list)
+	if (!objrefs || !obj->profile_list)
 		return NULL;
 
 	return g_hash_table_lookup (objrefs, obj);
@@ -96,21 +92,20 @@ CORBA_Object_release_cb (ORBit_RootObject robj)
 	if (obj->profile_list)
 		g_hash_table_remove (objrefs, obj);
 
-	if (obj->connection) {
-/*    g_warning("Release object '%p's connection", obj); */
-		giop_connection_close (obj->connection);
-		g_object_unref (G_OBJECT (obj->connection));
-	}
-
 	ORBit_free_T (obj->object_key);
 
-	IOP_delete_profiles (&obj->profile_list);
-	IOP_delete_profiles (&obj->forward_locations);
+	IOP_delete_profiles (obj->orb, &obj->profile_list);
+	IOP_delete_profiles (obj->orb, &obj->forward_locations);
+
+	if (obj->adaptor_obj) {
+		obj->adaptor_obj->objref = NULL;
 
-	if (obj->adaptor_obj)
 		ORBit_RootObject_release_T (obj->adaptor_obj);
+	}
 
-	g_free (obj);
+	giop_connection_unref (obj->connection);
+
+	p_free (obj, struct CORBA_Object_type);
 }
 
 static ORBit_RootObject_Interface objref_if = {
@@ -149,13 +144,30 @@ ORBit_objref_find (CORBA_ORB   orb,
 
 	retval = ORBit_lookup_objref (&fakeme);
 
+	dprintf (OBJECTS, "Lookup '%s' (%p) == %p\n", type_id, profiles, retval);
+
+#ifdef G_ENABLE_DEBUG
+	if (_orbit_debug_flags & ORBIT_DEBUG_OBJECTS) {
+		GSList *l;
+		fprintf (stderr, "Profiles: ");
+		for (l = profiles; l; l = l->next) {
+			char *str;
+			fprintf (stderr, "%s", (str = IOP_profile_dump (&fakeme, l->data)));
+			g_free (str);
+		}
+		fprintf (stderr, "\n");
+	}
+#endif /* G_ENABLE_DEBUG */
+
 	if (!retval) {
 		retval = ORBit_objref_new (orb, fakeme.type_qid);
 		retval->profile_list = profiles;
 		retval->object_key   = fakeme.object_key;
 		ORBit_register_objref (retval);
-	} else
-		IOP_delete_profiles (&profiles);
+	} else {
+		ORBit_free_T (fakeme.object_key);
+		IOP_delete_profiles (orb, &profiles);
+	}
 
 	retval = ORBit_RootObject_duplicate_T (retval);
 
@@ -174,6 +186,9 @@ ORBit_objref_find (CORBA_ORB   orb,
  * doesn't register in the global object / profile hash.
  *
  *  You almost certainly don't want to use this routine.
+ *
+ * FIXME: we should have an ORB wide 'socketpair' profile
+ * that is private for purely in-proc local loopback support.
  * 
  * Return value: a proxy object
  **/
@@ -193,49 +208,6 @@ ORBit_objref_get_proxy (CORBA_Object obj)
 	return ORBit_RootObject_duplicate (iobj);
 }
 
-void
-ORBit_start_servers (CORBA_ORB orb)
-{
-	LINCProtocolInfo *info;
-
-	for (info = linc_protocol_all (); info->name; info++) {
-		GIOPServer           *server;
-		LINCConnectionOptions options = 0;
-
-		if (!ORBit_proto_use (info->name))
-			continue;
-
-#ifndef ORBIT_THREADED
-		options |= LINC_CONNECTION_NONBLOCKING;
-#endif
-		server = giop_server_new (orb->default_giop_version,
-					  info->name, NULL, NULL,
-					  options, orb);
-		if (server) {
-			orb->servers = g_slist_prepend (orb->servers, server);
-
-			if (!(info->flags & LINC_PROTOCOL_SECURE)) {
-				if (!ORBit_proto_use ("SSL"))
-					continue;
-
-				server = giop_server_new (
-					orb->default_giop_version, info->name,
-					NULL, NULL, LINC_CONNECTION_SSL, orb);
-
-				if (server)
-					orb->servers = g_slist_prepend (orb->servers, server);
-			}
-#ifdef DEBUG
-			fprintf (stderr, "ORB created giop server '%s'\n", info->name);
-#endif
-		}
-#ifdef DEBUG
-		else
-			fprintf (stderr, "ORB failed to create giop server '%s'\n", info->name);
-#endif
-	}
-}
-
 static gboolean
 ORBit_try_connection (CORBA_Object obj)
 {
@@ -250,8 +222,7 @@ ORBit_try_connection (CORBA_Object obj)
 			break;
 
 		case LINC_DISCONNECTED:
-			if (obj->connection)
-				g_object_unref (G_OBJECT (obj->connection));
+			giop_connection_unref (obj->connection);
 			obj->connection = NULL;
 			return FALSE;
 			break;
@@ -298,10 +269,10 @@ ORBit_object_get_connection (CORBA_Object obj)
 			if (ORBit_try_connection (obj)) {
 				obj->object_key = objkey;
 				obj->connection->orb_data = obj->orb;
-#ifdef DEBUG
-				fprintf (stderr, "Initiated a connection to '%s' '%s' '%s'\n",
+
+				dprintf (OBJECTS, "Initiated a connection to '%s' '%s' '%s'\n",
 					 proto, host, service);
-#endif
+
 				return obj->connection;
 			}
 		}
@@ -315,12 +286,12 @@ ORBit_handle_location_forward (GIOPRecvBuffer *buf,
 			       CORBA_Object    obj)
 {
 	GIOPConnection *retval = NULL;
-	GSList *profiles;
+	GSList         *profiles = NULL;
 
 	if (ORBit_demarshal_IOR (obj->orb, buf, NULL, &profiles))
 		goto out;
 
-	IOP_delete_profiles (&obj->forward_locations);
+	IOP_delete_profiles (obj->orb, &obj->forward_locations);
 
 	obj->forward_locations = profiles;
 
@@ -362,8 +333,8 @@ CORBA_Object_release (CORBA_Object        obj,
 }
 
 CORBA_boolean
-CORBA_Object_non_existent(CORBA_Object       obj,
-			  CORBA_Environment *ev)
+CORBA_Object_non_existent (CORBA_Object       obj,
+			   CORBA_Environment *ev)
 {
 	ORBit_OAObject adaptor_obj;
 
@@ -377,14 +348,20 @@ CORBA_Object_non_existent(CORBA_Object       obj,
 	return ORBit_object_get_connection (obj) ? CORBA_FALSE : CORBA_TRUE;
 }
 
+/*
+ * We already ensure uniqueness of the CORBA_Object structure
+ */
 CORBA_boolean
-CORBA_Object_is_equivalent(CORBA_Object       obj,
-			   CORBA_Object       other_object,
-			   CORBA_Environment *ev)
+CORBA_Object_is_equivalent (CORBA_Object       obj,
+			    CORBA_Object       other_object,
+			    CORBA_Environment *ev)
 {
-	return g_CORBA_Object_equal (obj, other_object);
+	return obj == other_object;
 }
 
+/*
+ * We already ensure uniqueness of the CORBA_Object structure
+ */
 CORBA_unsigned_long
 CORBA_Object_hash (CORBA_Object              obj,
 		   const CORBA_unsigned_long maximum,
@@ -392,7 +369,7 @@ CORBA_Object_hash (CORBA_Object              obj,
 {
 	CORBA_unsigned_long retval;
 
-	retval = g_CORBA_Object_hash (obj);
+	retval = GPOINTER_TO_UINT (obj);
 
 	return maximum ? (retval % maximum) : retval;
 }
@@ -442,7 +419,6 @@ ORBit_marshal_object (GIOPSendBuffer *buf, CORBA_Object obj)
 {
 	GSList             *cur;
 	const char         *typeid;
-	CORBA_unsigned_long type_len;
 	CORBA_unsigned_long num_profiles;
 
 	if (obj)
@@ -450,9 +426,7 @@ ORBit_marshal_object (GIOPSendBuffer *buf, CORBA_Object obj)
 	else
 		typeid = "";
 
-	type_len = strlen (typeid) + 1;
-	giop_send_buffer_append_aligned (buf, &type_len, 4);
-	giop_send_buffer_append (buf, typeid, type_len);
+	giop_send_buffer_append_string (buf, typeid);
 
 	if (obj) {
 		if (!obj->profile_list)
@@ -463,14 +437,18 @@ ORBit_marshal_object (GIOPSendBuffer *buf, CORBA_Object obj)
 		num_profiles = 0;
 	giop_send_buffer_append_aligned (buf, &num_profiles, 4);
 
-#ifdef DEBUG
-	fprintf (stderr, "Marshal object '%p'\n", obj);
-#endif
+	dprintf (OBJECTS, "Marshal object '%p'\n", obj);
+
 	if (obj)
 		for (cur = obj->profile_list; cur; cur = cur->next) {
-#ifdef DEBUG
-			fprintf (stderr, "%s\n", IOP_profile_dump (obj, cur->data));
-#endif
+#ifdef G_ENABLE_DEBUG
+			if (_orbit_debug_flags & ORBIT_DEBUG_OBJECTS) {
+				char *str;
+				fprintf (stderr, "%s\n",
+					 (str = IOP_profile_dump (obj, cur->data)));
+				g_free (str);
+			}
+#endif /* G_ENABLE_DEBUG */
 			IOP_profile_marshal (obj, buf, cur->data);
 		}
 }
@@ -480,8 +458,8 @@ ORBit_demarshal_object (CORBA_Object   *obj,
 			GIOPRecvBuffer *buf,
 			CORBA_ORB       orb)
 {
-	char   *type_id;
-	GSList *profiles;
+	gchar  *type_id = NULL;
+	GSList *profiles = NULL;
 
 	if (ORBit_demarshal_IOR (orb, buf, &type_id, &profiles))
 		return TRUE;
@@ -494,12 +472,6 @@ ORBit_demarshal_object (CORBA_Object   *obj,
 	return FALSE;
 }
 
-gpointer
-CORBA_Object__freekids (gpointer mem, gpointer dat)
-{
-	return mem + sizeof (CORBA_Object);
-}
-
 CORBA_boolean
 CORBA_Object_is_a (CORBA_Object       obj,
 		   const CORBA_char  *logical_type_id,
