@@ -24,51 +24,55 @@
 
 static
 CORBA_char *
-BasicServer__get_foo(PortableServer_Servant servant,
-					 CORBA_Environment *ev) {
-  return CORBA_string_dup(constants_STRING_RETN);  
+BasicServer__get_foo (PortableServer_Servant servant,
+		      CORBA_Environment     *ev)
+{
+	return CORBA_string_dup (constants_STRING_RETN);  
 }
 
-
 static
 void
-BasicServer__set_foo(PortableServer_Servant servant,
-					 const CORBA_char *val,
-					 CORBA_Environment *ev) {
-  g_assert(strcmp(val,constants_STRING_IN)==0);
+BasicServer__set_foo (PortableServer_Servant servant,
+		      const CORBA_char      *val,
+		      CORBA_Environment     *ev)
+{
+	g_assert (!strcmp (val, constants_STRING_IN));
 }
 
 static
 CORBA_long
-BasicServer__get_bah(PortableServer_Servant servant,
-					 CORBA_Environment *ev) {
-  return constants_LONG_RETN;
+BasicServer__get_bah (PortableServer_Servant servant,
+		      CORBA_Environment     *ev)
+{
+	return constants_LONG_RETN;
 }
 
-
 static  
 CORBA_char *
-BasicServer_opString(PortableServer_Servant servant,
-					 const CORBA_char* inArg, 
-					 CORBA_char **inoutArg,
-					 CORBA_char **outArg,
-					 CORBA_Environment *ev) {
-  g_assert(strcmp(inArg,constants_STRING_IN)==0);
-  g_assert(strcmp(*inoutArg,constants_STRING_INOUT_IN)==0);
+BasicServer_opString (PortableServer_Servant servant,
+		      const CORBA_char* inArg, 
+		      CORBA_char **inoutArg,
+		      CORBA_char **outArg,
+		      CORBA_Environment *ev)
+{
+	g_assert (!strcmp (inArg, constants_STRING_IN));
+	g_assert (!strcmp (*inoutArg, constants_STRING_INOUT_IN));
   
-  CORBA_free(*inoutArg);
-  *inoutArg = CORBA_string_dup(constants_STRING_INOUT_OUT);
-  *outArg = CORBA_string_dup(constants_STRING_OUT);
-  return CORBA_string_dup(constants_STRING_RETN);
+	CORBA_free (*inoutArg);
+	*inoutArg = CORBA_string_dup (constants_STRING_INOUT_OUT);
+	*outArg = CORBA_string_dup (constants_STRING_OUT);
+
+	return CORBA_string_dup (constants_STRING_RETN);
 }
 
 static  
 CORBA_long
 BasicServer_opLong(PortableServer_Servant servant,
-					 const CORBA_long inArg, 
-					 CORBA_long *inoutArg,
-					 CORBA_long *outArg,
-					 CORBA_Environment *ev) {
+		   const CORBA_long inArg, 
+		   CORBA_long *inoutArg,
+		   CORBA_long *outArg,
+		   CORBA_Environment *ev)
+{
   g_assert(inArg == constants_LONG_IN);
   g_assert(*inoutArg == constants_LONG_INOUT_IN);
   
@@ -77,13 +81,30 @@ BasicServer_opLong(PortableServer_Servant servant,
   return constants_LONG_RETN;
 }
 
+static  
+CORBA_long_long
+BasicServer_opLongLong(PortableServer_Servant servant,
+		       const CORBA_long_long inArg, 
+		       CORBA_long_long *inoutArg,
+		       CORBA_long_long *outArg,
+		       CORBA_Environment *ev)
+{
+  g_assert(inArg == constants_LONG_LONG_IN);
+  g_assert(*inoutArg == constants_LONG_LONG_INOUT_IN);
+  
+  *inoutArg = constants_LONG_LONG_INOUT_OUT;
+  *outArg = constants_LONG_LONG_OUT;;
+  return constants_LONG_LONG_RETN;
+}
+
 static  
 test_AnEnum
 BasicServer_opEnum(PortableServer_Servant servant,
-					 const test_AnEnum inArg, 
-					 test_AnEnum *inoutArg,
-					 test_AnEnum *outArg,
-					 CORBA_Environment *ev) {
+		   const test_AnEnum inArg, 
+		   test_AnEnum *inoutArg,
+		   test_AnEnum *outArg,
+		   CORBA_Environment *ev)
+{
   g_assert(inArg == test_ENUM_IN);
   g_assert(*inoutArg == test_ENUM_INOUT_IN);
   
@@ -96,7 +117,8 @@ BasicServer_opEnum(PortableServer_Servant servant,
 static  
 void
 BasicServer_opException(PortableServer_Servant servant,
-				   CORBA_Environment *ev) {
+			CORBA_Environment *ev)
+{
   test_TestException *ex = test_TestException__alloc();
   ex->reason=CORBA_string_dup(constants_STRING_IN);
   ex->number = constants_LONG_IN;
@@ -109,7 +131,20 @@ BasicServer_opException(PortableServer_Servant servant,
   CORBA_exception_set(ev,CORBA_USER_EXCEPTION,ex_test_TestException,ex);
 }
 
+static void
+BasicServer_opOneWay (PortableServer_Servant servant,
+		      const CORBA_char      *str,
+		      CORBA_Environment     *ev)
+{
+	g_assert (!strcmp (str, constants_STRING_IN));
+}
 
+static void
+BasicServer_testLargeStringSeq (PortableServer_Servant servant,
+				const test_StrSeq     *seq,
+				CORBA_Environment     *ev)
+{
+}
 
 PortableServer_ServantBase__epv BasicServer_base_epv = {NULL,NULL,NULL};
 
@@ -120,8 +155,12 @@ POA_test_BasicServer__epv BasicServer_epv = {
   BasicServer__get_bah,
   BasicServer_opString,
   BasicServer_opLong,
+  BasicServer_opLongLong,
   BasicServer_opEnum,
   BasicServer_opException,
+  BasicServer_opOneWay,
+  NULL, /* noImplement */
+  BasicServer_testLargeStringSeq
 };
 
 POA_test_BasicServer__vepv BasicServer_vepv = {&BasicServer_base_epv,&BasicServer_epv};
