@@ -25,6 +25,7 @@
 
 #include "everything.h"
 #include "constants.h"
+#include "orb-core/orb-core-private.h"
 
 #define NUM_RUNS 1
 
@@ -1035,6 +1036,9 @@ make_large_str_seq (void)
 		seq->_buffer [i] [len] = '\0';
 	}
 
+	seq->_length = seq->_maximum = SEQ_SIZE;
+	seq->_release = CORBA_TRUE;
+
 	return seq;
 }
 
@@ -1056,6 +1060,7 @@ testMisc (test_TestFactory   factory,
 		CORBA_exception_free (ev);
 	}
 	
+	g_assert (ORBit_copy_value (NULL, TC_CORBA_boolean) == NULL);
 
 	objref = test_TestFactory_getBasicServer (factory, ev);
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
@@ -1075,7 +1080,6 @@ testMisc (test_TestFactory   factory,
 		test_BasicServer_testLargeStringSeq (objref, seq, ev);
 		g_assert (ev->_major == CORBA_NO_EXCEPTION);
 		CORBA_free (seq);
-
 	}
 
 	CORBA_Object_release (objref, ev);
@@ -1442,7 +1446,6 @@ testSegv (test_TestFactory   factory,
 	if (!in_proc) {
 		gboolean broken = FALSE;
 		gboolean invoked = FALSE;
-		CORBA_char *id;
 
 		g_assert (ORBit_small_listen_for_broken (
 			factory, G_CALLBACK (broken_cb), &broken) ==
@@ -1456,7 +1459,7 @@ testSegv (test_TestFactory   factory,
 			factory, G_CALLBACK (dummy_cb)) ==
 			  ORBIT_CONNECTION_CONNECTED);
 
-		id = test_TestFactory_segv (factory, "do it!", ev); 
+		test_TestFactory_segv (factory, "do it!", ev); 
 #ifdef DO_HARDER_SEGV
 		g_assert (ev->_major == CORBA_SYSTEM_EXCEPTION);
 		g_assert (!strcmp (ev->_id, "IDL:CORBA/COMM_FAILURE:1.0"));
@@ -1472,7 +1475,6 @@ testSegv (test_TestFactory   factory,
 		    ORBIT_CONNECTION_CONNECTED)
 			g_warning ("Unusual race in unlisten");
 		g_assert (ev->_major == CORBA_NO_EXCEPTION);
-		CORBA_free (id);
 #endif
 	}
 }
@@ -1562,6 +1564,37 @@ run_tests (test_TestFactory   factory,
 #endif
 }
 
+static void
+dump_protos (void)
+{
+	int enabled_count = 0;
+	LINCProtocolInfo *info;
+
+	for (info = linc_protocol_all (); info->name; info++) {
+		gboolean enabled;
+
+		if ((enabled = ORBit_proto_use (info->name)))
+			enabled_count++;
+
+		fprintf (stderr, "Protocol %8s: %s\n",
+			 info->name, 
+			 enabled ? "enabled" : "disabled");
+	}
+
+	g_assert (enabled_count > 0);
+}
+
+static void
+test_init (CORBA_Environment *ev)
+{
+	g_assert (CORBA_ORB_init (NULL, NULL, "", ev) == global_orb);
+	g_assert (ev->_major == CORBA_NO_EXCEPTION);
+
+	CORBA_ORB_destroy (global_orb, ev);
+	g_assert (ev->_major == CORBA_NO_EXCEPTION);
+	CORBA_Object_release ((CORBA_Object)global_orb, ev);
+}
+
 int
 main (int argc, char *argv [])
 {
@@ -1576,10 +1609,13 @@ main (int argc, char *argv [])
 	global_orb = CORBA_ORB_init (&argc, argv, "", &ev);
 	g_assert (ev._major == CORBA_NO_EXCEPTION);
 
+	test_init (&ev);
 	test_initial_references (global_orb, &ev);
 
 	free (malloc (8)); /* -lefence */
 
+	dump_protos ();
+
 	/* In Proc ... */
 	in_proc = TRUE;
 
